@@ -13,8 +13,9 @@ gbt_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
   gbt_args$data_filter <- if (input$show_filter) input$data_filter else ""
   gbt_args$dataset <- input$dataset
-  for (i in r_drop(names(gbt_args)))
+  for (i in r_drop(names(gbt_args))) {
     gbt_args[[i]] <- input[[paste0("gbt_", i)]]
+  }
   gbt_args
 })
 
@@ -27,8 +28,9 @@ gbt_pred_args <- as.list(if (exists("predict.gbt")) {
 # list of function inputs selected by user
 gbt_pred_inputs <- reactive({
   # loop needed because reactive values don't allow single bracket indexing
-  for (i in names(gbt_pred_args))
+  for (i in names(gbt_pred_args)) {
     gbt_pred_args[[i]] <- input[[paste0("gbt_", i)]]
+  }
 
   gbt_pred_args$pred_cmd <- gbt_pred_args$pred_data <- ""
   if (input$gbt_predict == "cmd") {
@@ -50,13 +52,14 @@ gbt_pred_plot_args <- as.list(if (exists("plot.model.predict")) {
   formals(plot.model.predict)
 } else {
   formals(radiant.model:::plot.model.predict)
-} )
+})
 
 # list of function inputs selected by user
 gbt_pred_plot_inputs <- reactive({
   # loop needed because reactive values don't allow single bracket indexing
-  for (i in names(gbt_pred_plot_args))
+  for (i in names(gbt_pred_plot_args)) {
     gbt_pred_plot_args[[i]] <- input[[paste0("gbt_", i)]]
+  }
   gbt_pred_plot_args
 })
 
@@ -103,7 +106,9 @@ output$ui_gbt_lev <- renderUI({
 })
 
 output$ui_gbt_evar <- renderUI({
-  if (not_available(input$gbt_rvar)) return()
+  if (not_available(input$gbt_rvar)) {
+    return()
+  }
   vars <- varnames()
   if (length(vars) > 0) {
     vars <- vars[-which(vars == input$gbt_rvar)]
@@ -134,7 +139,7 @@ output$ui_gbt_wts <- renderUI({
   if (length(vars) > 0 && any(vars %in% input$gbt_evar)) {
     vars <- base::setdiff(vars, input$gbt_evar)
     names(vars) <- varnames() %>%
-      {.[match(vars, .)]} %>%
+      (function(x) x[match(vars, x)]) %>%
       names()
   }
   vars <- c("None", vars)
@@ -182,7 +187,8 @@ output$ui_gbt_plots <- renderUI({
     gbt_plots <- head(gbt_plots, -1)
   }
   selectInput(
-    "gbt_plots", "Plots:", choices = gbt_plots,
+    "gbt_plots", "Plots:",
+    choices = gbt_plots,
     selected = state_single("gbt_plots", gbt_plots)
   )
 })
@@ -204,16 +210,18 @@ run_refresh(gbt_args, "gbt", tabs = "tabs_gbt", label = "Estimate model", relabe
 output$ui_gbt <- renderUI({
   req(input$dataset)
   tagList(
-    conditionalPanel(condition = "input.tabs_gbt == 'Summary'",
+    conditionalPanel(
+      condition = "input.tabs_gbt == 'Summary'",
       wellPanel(
-        actionButton("gbt_run", "Estimate model", width = "100%", icon = icon("play"), class = "btn-success")
+        actionButton("gbt_run", "Estimate model", width = "100%", icon = icon("play", verify_fa = FALSE), class = "btn-success")
       )
     ),
     wellPanel(
       conditionalPanel(
         condition = "input.tabs_gbt == 'Summary'",
         radioButtons(
-          "gbt_type", label = NULL, c("classification", "regression"),
+          "gbt_type",
+          label = NULL, c("classification", "regression"),
           selected = state_init("gbt_type", "classification"),
           inline = TRUE
         ),
@@ -224,56 +232,69 @@ output$ui_gbt <- renderUI({
         with(tags, table(
           tr(
             td(numericInput(
-              "gbt_max_depth", label = "Max depth:", min = 1, max = 20,
+              "gbt_max_depth",
+              label = "Max depth:", min = 1, max = 20,
               value = state_init("gbt_max_depth", 6)
             ), width = "50%"),
             td(numericInput(
-              "gbt_learning_rate", label = "Learning rate:", min = 0, max = 1, step = 0.1,
+              "gbt_learning_rate",
+              label = "Learning rate:", min = 0, max = 1, step = 0.1,
               value = state_init("gbt_learning_rate", 0.3)
             ), width = "50%")
-          ), width = "100%"
+          ),
+          width = "100%"
         )),
         with(tags, table(
           tr(
             td(numericInput(
-              "gbt_min_split_loss", label = "Min split loss:", min = 0.00001, max = 1000,
+              "gbt_min_split_loss",
+              label = "Min split loss:", min = 0.00001, max = 1000,
               step = 0.01, value = state_init("gbt_min_split_loss", 0)
             ), width = "50%"),
             td(numericInput(
-              "gbt_min_child_weight", label = "Min child weight:", min = 1, max = 100,
+              "gbt_min_child_weight",
+              label = "Min child weight:", min = 1, max = 100,
               step = 1, value = state_init("gbt_min_child_weight", 1)
             ), width = "50%")
-          ), width = "100%"
+          ),
+          width = "100%"
         )),
         with(tags, table(
           tr(
             td(numericInput(
-              "gbt_subsample", label = "Sub-sample:", min = 0.1, max = 1,
+              "gbt_subsample",
+              label = "Sub-sample:", min = 0.1, max = 1,
               value = state_init("gbt_subsample", 1)
             ), width = "50%"),
             td(numericInput(
-              "gbt_nrounds", label = "# rounds:",
+              "gbt_nrounds",
+              label = "# rounds:",
               value = state_init("gbt_nrounds", 100)
             ), width = "50%")
-          ), width = "100%"
+          ),
+          width = "100%"
         )),
         with(tags, table(
           tr(
             td(numericInput(
-              "gbt_early_stopping_rounds", label = "Early stopping:", min = 1, max = 10,
+              "gbt_early_stopping_rounds",
+              label = "Early stopping:", min = 1, max = 10,
               step = 1, value = state_init("gbt_early_stopping_rounds", 3)
             ), width = "50%"),
             td(numericInput(
-              "gbt_seed", label = "Seed:",
+              "gbt_seed",
+              label = "Seed:",
               value = state_init("gbt_seed", 1234)
             ), width = "50%")
-          ), width = "100%"
+          ),
+          width = "100%"
         ))
       ),
       conditionalPanel(
         condition = "input.tabs_gbt == 'Predict'",
         selectInput(
-          "gbt_predict", label = "Prediction input type:", reg_predict,
+          "gbt_predict",
+          label = "Prediction input type:", reg_predict,
           selected = state_single("gbt_predict", reg_predict, "none")
         ),
         conditionalPanel(
@@ -307,7 +328,7 @@ output$ui_gbt <- renderUI({
           "input.gbt_predict == 'data' | input.gbt_predict == 'datacmd'",
           tags$table(
             tags$td(uiOutput("ui_gbt_store_pred_name")),
-            tags$td(actionButton("gbt_store_pred", "Store", icon = icon("plus")), class = "top")
+            tags$td(actionButton("gbt_store_pred", "Store", icon = icon("plus", verify_fa = FALSE)), class = "top")
           )
         )
       ),
@@ -323,7 +344,7 @@ output$ui_gbt <- renderUI({
       #   condition = "input.tabs_gbt == 'Summary'",
       #   tags$table(
       #     tags$td(uiOutput("ui_gbt_store_res_name")),
-      #     tags$td(actionButton("gbt_store_res", "Store", icon = icon("plus")), class = "top")
+      #     tags$td(actionButton("gbt_store_res", "Store", icon = icon("plus", verify_fa = FALSE)), class = "top")
       #   )
       # )
     ),
@@ -337,15 +358,21 @@ output$ui_gbt <- renderUI({
 
 gbt_plot <- reactive({
   # req(input$gbt_plots)
-  if (gbt_available() != "available") return()
-  if (radiant.data::is_empty(input$gbt_plots, "none")) return()
+  if (gbt_available() != "available") {
+    return()
+  }
+  if (radiant.data::is_empty(input$gbt_plots, "none")) {
+    return()
+  }
   res <- .gbt()
-  if (is.character(res)) return()
+  if (is.character(res)) {
+    return()
+  }
   nr_vars <- length(res$evar)
   if ("dashboard" %in% input$gbt_plots) {
     plot_height <- 750
   } else if ("pdp" %in% input$gbt_plots) {
-    plot_height <- max(500, (nr_vars/2) * 250)
+    plot_height <- max(500, (nr_vars / 2) * 250)
   } else if ("vimp" %in% input$gbt_plots) {
     plot_height <- max(300, nr_vars * 50)
   } else {
@@ -355,14 +382,19 @@ gbt_plot <- reactive({
   list(plot_width = 650, plot_height = plot_height)
 })
 
-gbt_plot_width <- function()
-  gbt_plot() %>% {if (is.list(.)) .$plot_width else 650}
+gbt_plot_width <- function() {
+  gbt_plot() %>%
+    (function(x) if (is.list(x)) x$plot_width else 650)
+}
 
-gbt_plot_height <- function()
-  gbt_plot() %>% {if (is.list(.)) .$plot_height else 500}
+gbt_plot_height <- function() {
+  gbt_plot() %>%
+    (function(x) if (is.list(x)) x$plot_height else 500)
+}
 
-gbt_pred_plot_height <- function()
+gbt_pred_plot_height <- function() {
   if (input$gbt_pred_plot) 500 else 1
+}
 
 ## output is called from the main radiant ui.R
 output$gbt <- renderUI({
@@ -451,15 +483,25 @@ gbt_available <- reactive({
 })
 
 .summary_gbt <- reactive({
-  if (not_pressed(input$gbt_run)) return("** Press the Estimate button to estimate the model **")
-  if (gbt_available() != "available") return(gbt_available())
+  if (not_pressed(input$gbt_run)) {
+    return("** Press the Estimate button to estimate the model **")
+  }
+  if (gbt_available() != "available") {
+    return(gbt_available())
+  }
   summary(.gbt())
 })
 
 .predict_gbt <- reactive({
-  if (not_pressed(input$gbt_run)) return("** Press the Estimate button to estimate the model **")
-  if (gbt_available() != "available") return(gbt_available())
-  if (radiant.data::is_empty(input$gbt_predict, "none")) return("** Select prediction input **")
+  if (not_pressed(input$gbt_run)) {
+    return("** Press the Estimate button to estimate the model **")
+  }
+  if (gbt_available() != "available") {
+    return(gbt_available())
+  }
+  if (radiant.data::is_empty(input$gbt_predict, "none")) {
+    return("** Select prediction input **")
+  }
 
   if ((input$gbt_predict == "data" || input$gbt_predict == "datacmd") && radiant.data::is_empty(input$gbt_pred_data)) {
     return("** Select data for prediction **")
@@ -477,9 +519,8 @@ gbt_available <- reactive({
 })
 
 .predict_print_gbt <- reactive({
-  .predict_gbt() %>% {
-    if (is.character(.)) cat(., "\n") else print(.)
-  }
+  .predict_gbt() %>%
+    (function(x) if (is.character(x)) cat(x, "\n") else print(x))
 })
 
 .predict_plot_gbt <- reactive({
@@ -529,7 +570,9 @@ gbt_available <- reactive({
 observeEvent(input$gbt_store_pred, {
   req(!radiant.data::is_empty(input$gbt_pred_data), pressed(input$gbt_run))
   pred <- .predict_gbt()
-  if (is.null(pred)) return()
+  if (is.null(pred)) {
+    return()
+  }
   fixed <- fix_names(input$gbt_store_pred_name)
   updateTextInput(session, "gbt_store_pred_name", value = fixed)
   withProgress(
@@ -541,8 +584,10 @@ observeEvent(input$gbt_store_pred, {
   )
 })
 
-observeEvent(input$gbt_report, {
-  if (radiant.data::is_empty(input$gbt_rvar)) return(invisible())
+gbt_report <- function() {
+  if (radiant.data::is_empty(input$gbt_rvar)) {
+    return(invisible())
+  }
 
   outputs <- c("summary")
   inp_out <- list(list(prn = TRUE), "")
@@ -588,7 +633,8 @@ observeEvent(input$gbt_report, {
     if (input$gbt_predict %in% c("data", "datacmd")) {
       fixed <- fix_names(input$gbt_store_pred_name)
       updateTextInput(session, "gbt_store_pred_name", value = fixed)
-      xcmd <- paste0(xcmd, "\n", input$gbt_pred_data , " <- store(",
+      xcmd <- paste0(
+        xcmd, "\n", input$gbt_pred_data, " <- store(",
         input$gbt_pred_data, ", pred, name = \"", fixed, "\")"
       )
     }
@@ -616,7 +662,7 @@ observeEvent(input$gbt_report, {
     fig.height = gbt_plot_height(),
     xcmd = xcmd
   )
-})
+}
 
 dl_gbt_pred <- function(path) {
   if (pressed(input$gbt_run)) {
@@ -655,3 +701,18 @@ download_handler(
   width = gbt_plot_width,
   height = gbt_plot_height
 )
+
+observeEvent(input$gbt_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  gbt_report()
+})
+
+observeEvent(input$gbt_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_gbt_screenshot")
+})
+
+observeEvent(input$modal_gbt_screenshot, {
+  gbt_report()
+  removeModal() ## remove shiny modal after save
+})
\ No newline at end of file
